@@ -40,5 +40,28 @@ public:
 };
 }; // namespace enum_container_ns
 
+// enum in a namespace in a nested class
+namespace enum_container_ns {
+class NSEnumContainer2 {
+public:
+  class InnerEnumContainer {
+    public:
+    enum MoreInnerEnum { NSIEMIE1 = 1 };
+    enum class MoreInnerCEnum { NSIEMIEC1 = 1 };
+  };
+  
+};
+}; // namespace enum_container_ns
+
+
 // strip prefix
-enum StripPrefixEnum { STRIP_1 = 1, STRIP_B = 2 };
\ No newline at end of file
+enum StripPrefixEnum { STRIP_1 = 1, STRIP_B = 2 };
+
+// global enum with arithmetic
+enum GEnumMath { MGE1 = 1 };
+
+// enum with arithmetic in a class
+class EnumContainer2 {
+public:
+  enum InnerMathEnum { IME1 = 1 };
+};
